@@ -1,5 +1,5 @@
 #ifndef __INCLUDE_MY_SQLITE3_H__
-#define __INCLUDE_MY_SQLITE3_H__
+#define __INCLUDE_MY_SQLITE3_H__ 1
 
 #include <EXTERN.h>
 #include <perl.h>
@@ -14,6 +14,14 @@
 #undef DWORD
 #define DWORD unsigned long
 
+#undef UPTR
+#define UPTR void *
+
+#undef HAS_UV64
+#if UVSIZE == 8
+#	define HAS_UV64 1
+#endif
+
 #define MYCF_TRANSACTION	1
 #define MYCF_AUTOCOMMIT		2
 
@@ -21,6 +29,19 @@
 #define MY_TYPE_RES		2
 #define MY_TYPE_STMT	3
 
+#undef XLONG
+#undef UXLONG
+#if defined __unix__
+#	define XLONG long long
+#	define UXLONG unsigned long long
+#elif defined __WIN__
+#	define XLONG __int64
+#	define UXLONG unsigned __int64
+#else
+#	define XLONG long
+#	define UXLONG unsigned long
+#endif
+
 typedef char **MY_ROW;
 
 typedef struct st_my_rows {
@@ -89,13 +110,15 @@ unsigned long get_current_thread_id();
 char *my_strcpy( char *dst, const char *src );
 int my_stricmp( const char *cs, const char *ct );
 char *my_stristr( const char *str1, const char *str2 );
+char *my_itoa( char *str, long value, int radix );
+char *my_ltoa( char *str, XLONG value, int radix );
 
 void my_init( my_cxt_t *cxt );
 void my_cleanup( my_cxt_t *cxt );
 void my_session_cleanup( my_cxt_t *cxt );
 
-U32 my_verify_linkid( my_cxt_t *cxt, U32 linkid );
-int my_get_type( my_cxt_t *cxt, U32 *ptr );
+UPTR my_verify_linkid( my_cxt_t *cxt, UPTR linkid );
+int my_get_type( my_cxt_t *cxt, UPTR *ptr );
 void my_set_error( my_cxt_t *cxt, const char *tpl, ... );
 
 MY_CON *my_con_add( my_cxt_t *cxt, sqlite3 *con, DWORD tid );
@@ -115,9 +138,9 @@ int my_result_exists( my_cxt_t *cxt, MY_RES *res );
 MY_STMT *my_stmt_add( MY_CON *con, sqlite3_stmt *pStmt );
 void my_stmt_rem( MY_STMT *stmt );
 void my_stmt_free( MY_STMT *stmt );
-int my_stmt_exists( my_cxt_t *cxt, U32 ptr );
+int my_stmt_exists( my_cxt_t *cxt, UPTR ptr );
 int my_stmt_bind_param( MY_STMT *stmt, int p_num, SV *val, char type );
-int my_stmt_or_res( my_cxt_t *cxt, U32 ptr );
-int my_stmt_or_con( my_cxt_t *cxt, U32 *ptr );
+int my_stmt_or_res( my_cxt_t *cxt, UPTR ptr );
+int my_stmt_or_con( my_cxt_t *cxt, UPTR *ptr );
 
 #endif
